# Authors

* [Jiří Setnička](https://github.com/setnicka)
  * **Primary maintainer and author**
* [Koticka](https://github.com/Koticka)
  * Automatic CAPTCHA recognition
* [SpiReCZ](https://github.com/SpiReCZ)
  * Frontend changes for easy usage as library, several fixes
* [filo891](https://github.com/filo891)
  * Logging, output and Tor enhancements
* [Petr Kejval](https://github.com/pkejval)
  * JSON frontend
* [MikulasZelinka](https://github.com/MikulasZelinka)
  * Support for tensorflow.lite
* [Jan Musílek](https://github.com/stinovlas)
  * Several fixes and ideas
* [VladoDriver](https://github.com/vladodriver)
  * Several small fixes and improvements
* [Lukáš Bačovský](https://github.com/xgimp)
  * Code refactoring
* [MarekVigas](https://github.com/MarekVigas)
  * Frontend enhancements (--parts-progress)

And several other authors with minor fixes and improvements.
